%bcond_with tests

%define major 10
%define crypto_major 1
%define x509_major 0
%define libname %mklibname %{name} %{major}
%define libcrypto %mklibname mbedcrypto %{crypto_major}
%define libx509 %mklibname mbedx509_ %{x509_major}
%define devname %mklibname %{name} -d

Summary:	An SSL library
Name:		mbedtls
Version:	2.8.0
Release:	2
License:	ASL 2.0
Group:		System/Libraries
Url:		https://tls.mbed.org
Source0:	https://tls.mbed.org/download/%{name}-%{version}-apache.tgz
BuildRequires:	cmake >= 2.8
# For docs
BuildRequires:	doxygen
BuildRequires:	graphviz
# For tests
%if %{with tests}
BuildRequires:	lcov
BuildRequires:	perl
BuildRequires:	valgrind
%endif
BuildRequires:	pkgconfig(libpkcs11-helper-1)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)

%description
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C. It
makes it easy for developers to include cryptographic and SSL/TLS capabilities
in their (embedded) products with as little hassle as possible. It is designed
to be readable, documented, tested, loosely coupled and portable.
This package contains mbed TLS programs.

%files
%doc ChangeLog README*
%{_bindir}/%{name}-*

#-----------------------------------------------------------------------------

%package -n %{libname}
Summary:	mbed TLS library
Group:		System/Libraries

%description -n %{libname}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C. It
makes it easy for developers to include cryptographic and SSL/TLS capabilities
in their (embedded) products with as little hassle as possible. It is designed
to be readable, documented, tested, loosely coupled and portable.
This package contains the library itself.

%files -n %{libname}
%doc LICENSE
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{version}

#-----------------------------------------------------------------------------

%package -n %{libcrypto}
Summary:	mbed TLS library
Group:		System/Libraries

%description -n %{libcrypto}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C. It
makes it easy for developers to include cryptographic and SSL/TLS capabilities
in their (embedded) products with as little hassle as possible. It is designed
to be readable, documented, tested, loosely coupled and portable.
This package contains the library itself.

%files -n %{libcrypto}
%doc LICENSE
%{_libdir}/libmbedcrypto.so.%{version}
%{_libdir}/libmbedcrypto.so.%{crypto_major}

#-----------------------------------------------------------------------------

%package -n %{libx509}
Summary:	mbed TLS library
Group:		System/Libraries

%description -n %{libx509}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C. It
makes it easy for developers to include cryptographic and SSL/TLS capabilities
in their (embedded) products with as little hassle as possible. It is designed
to be readable, documented, tested, loosely coupled and portable.
This package contains the library itself.

%files -n %{libx509}
%doc LICENSE
%{_libdir}/libmbedx509.so.%{version}
%{_libdir}/libmbedx509.so.%{x509_major}

#-----------------------------------------------------------------------------

%package -n %{devname}
Summary:	mbed TLS development files
Group:		Development/C
Requires:	%{libname} = %{EVRD}
Requires:	%{libcrypto} = %{EVRD}
Requires:	%{libx509} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}

%description -n	%{devname}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C. It
makes it easy for developers to include cryptographic and SSL/TLS capabilities
in their (embedded) products with as little hassle as possible. It is designed
to be readable, documented, tested, loosely coupled and portable.
This package contains development files for %{name}.

%files -n %{devname}
%doc apidoc/*
%{_libdir}/libmbed*.so
%{_includedir}/%{name}/

#-----------------------------------------------------------------------------

%prep
%setup -q

# (gvm) Perhaps it does apply also for us, perhaps it does not:
# in the doubt, keep it...
# Enable MBEDTLS_THREADING_PTHREAD and MBEDTLS_THREADING_C flags
# https://bugs.mageia.org/show_bug.cgi?id=15391#c4
sed -i -e 's|.*\(#define MBEDTLS_THREADING_C\)|\1|' \
	-e 's|.*\(#define MBEDTLS_THREADING_PTHREAD\)|\1|' \
	include/mbedtls/config.h

	
%build
%cmake \
	-DCMAKE_BUILD_TYPE:STRING=Release \
	-DUSE_SHARED_MBEDTLS_LIBRARY:BOOL=ON \
	-DUSE_STATIC_MBEDTLS_LIBRARY:BOOL=OFF \
	-DUSE_PKCS11_HELPER_LIBRARY:BOOL=ON
%make
# Build also devel docs
%make apidoc


%install
%makeinstall_std -C build

# Prevent possible file clashes
pushd %{buildroot}%{_bindir}
	for i in * ; do mv ${i} %{name}-${i}; done
popd

%if %{with tests}
%check
%make check
%endif

%changelog

* Mon May 07 2018 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.8.0-2
- (7ec778c) Disable tests by default


